/***********************************************************************************************
	File Name:		SimpleMailer.cs
	Purpose:		Class exposing simple static methods for sending email
	Author:			Jon Gilkison <jon.gilkison@interfacelab.com>
	Copyright:		2004 Interfacelab LLC                                                             
	Date:			3/23/2004
 ***********************************************************************************************/

using System;
using System.Web.Mail;

namespace commitmailer
{
	/// <summary>
	/// SimpleMailer provides simplified mail sending capabilities.
	/// </summary>
	public sealed class SimpleMailer
	{
		/// <summary>
		/// Singleton, no need to instantiate.
		/// </summary>
		private SimpleMailer()
		{
		}

		/// <summary>
		/// Sends an e-mail through the specified server to the specified recipient.
		/// </summary>
		/// <param name="smtpserver">The name of the SMTP server to use, leave blank to use the default local server.</param>
		/// <param name="from">The email address the email is from.</param>
		/// <param name="to">The email address or addresses to send the mail to.</param>
		/// <param name="cc">The email addresses to send copies of the email to.</param>
		/// <param name="bcc">The email addresses to send blind copies of the email to.</param>
		/// <param name="subject">The subject for the email.</param>
		/// <param name="body">The body text of the email, must be plain text.</param>
		/// <param name="attachments">A list of pathnames to attachments to be attached to this email.</param>
		public static void Send(string smtpserver, string from, string to, string cc, string bcc, string subject, string body, params string[] attachments)
		{
			// if the server was specified, assign it, otherwise use the default.
			if (smtpserver!=string.Empty)
				SmtpMail.SmtpServer=smtpserver;

			// create a new mail message
			MailMessage msg=new MailMessage();

			// assign the from and to fields
			msg.From=from;
			msg.To=to;

			// assign the cc
			if (cc!=string.Empty)
				msg.Cc=cc;

			// assign the bcc
			if (bcc!=string.Empty)
				msg.Bcc=bcc;

			// assign the subject and body
			msg.Subject=subject;
			msg.Body=body;

			// if any attachments were specified, add the to the outgoing mail.
			foreach(string st in attachments)
				msg.Attachments.Add(new MailAttachment(st));

			// send the puppy.
			SmtpMail.Send(msg);
		}
	}
}
